@@ -4,6 +4,7 @@ import logging
 import sys
 import os
 
+
 def read_project_version(py=None, where='.', exclude=['bootstrap', 'pavement', 'doc', 'docs', 'test', 'tests', ]):
     if not py:
         py = path(where) / find_packages(where=where, exclude=exclude)[0]
@@ -17,26 +18,27 @@ def read_project_version(py=None, where='.', exclude=['bootstrap', 'pavement', '
             break
     return __version__
 
-release = read_project_version(path('..').abspath() / 'sphinxcontrib' / 'programscreenshot.py')
+release = read_project_version(
+    path('..').abspath() / 'sphinxcontrib' / 'programscreenshot.py')
 
 project = u'sphinxcontrib-programscreenshot'
 copyright = u'2011, ponty'
 author = 'ponty'
 
 
-#logging.basicConfig(level=logging.DEBUG)
+# logging.basicConfig(level=logging.DEBUG)
 
 needs_sphinx = '1.0'
 
 extensions = [
-             #'sphinx.ext.intersphinx',
-              'sphinxcontrib.programscreenshot',
-             #'sphinx.ext.autodoc',
-             #'sphinxcontrib.programoutput',
-             #'sphinx.ext.graphviz',
-             #'sphinx.ext.autosummary',
-              ]
-#intersphinx_mapping = {'http://docs.python.org/': None,
+    #'sphinx.ext.intersphinx',
+    'sphinxcontrib.programscreenshot',
+    #'sphinx.ext.autodoc',
+    #'sphinxcontrib.programoutput',
+    #'sphinx.ext.graphviz',
+    #'sphinx.ext.autosummary',
+]
+# intersphinx_mapping = {'http://docs.python.org/': None,
 #'http://packages.python.org/sphinxcontrib-programoutput/' : None,
 #}
 
@@ -49,7 +51,7 @@ exclude_patterns = ['_build/*']
 html_theme = 'default'
 html_static_path = []
 
-#intersphinx_mapping = {
+# intersphinx_mapping = {
 #    'ansi': ('http://packages.python.org/sphinxcontrib-ansi', None)}
 
 
@@ -60,14 +62,14 @@ def setup(app):
 # latex build settings
 latex_documents = [
     ('index', '%s.tex' % project, u'%s Documentation' % project,
-    author, 'manual'),
+     author, 'manual'),
 ]
 
 # remove blank pages from pdf
-# http://groups.google.com/group/sphinx-dev/browse_thread/thread/92e19267d095412d/d60dcba483c6b13d
-latex_font_size = '10pt,oneside' 
+# http://groups.google.com/group/sphinx-
+# dev/browse_thread/thread/92e19267d095412d/d60dcba483c6b13d
+latex_font_size = '10pt,oneside'
 
-latex_elements=dict(
-                    papersize='a4paper',
-                    )
- 
+latex_elements = dict(
+    papersize='a4paper',
+)
