@@ -15,27 +15,33 @@ import path
 
 """
 
-__version__ = '0.0.4'
-   
+__version__ = '0.0.5'
+
 log = logging.getLogger(__name__)
 log.debug('sphinxcontrib.programscreenshot (version:%s)' % __version__)
 
+
 class ProgramScreenshotError(Exception):
     pass
 
+
+def get_src(self):
+    return self.state_machine.get_source(self.lineno)
+
+
 def prog_shot(cmd, f, wait, timeout, screen_size, visible, bgcolor):
     '''start process in headless X and create screenshot after 'wait' sec.
     Repeats screenshot until it is not empty if 'repeat_if_empty'=True.
 
     wait: wait at least N seconds after first window is displayed,
-    it can be used to skip splash screen 
+    it can be used to skip splash screen
 
-    :param enable_crop: True -> crop screenshot 
-    :param wait: int 
+    :param enable_crop: True -> crop screenshot
+    :param wait: int
     '''
     disp = SmartDisplay(visible=visible, size=screen_size, bgcolor=bgcolor)
     proc = EasyProcess(cmd)
-    
+
     def func():
         try:
             img = disp.waitgrab(timeout=timeout)
@@ -45,7 +51,7 @@ def prog_shot(cmd, f, wait, timeout, screen_size, visible, bgcolor):
             proc.sleep(wait)
             img = disp.grab()
         return img
-    
+
     img = disp.wrap(proc.wrap(func))()
     if img:
         img.save(f)
@@ -55,6 +61,8 @@ def prog_shot(cmd, f, wait, timeout, screen_size, visible, bgcolor):
 parent = docutils.parsers.rst.directives.images.Image
 images_to_delete = []
 image_id = 0
+
+
 class ProgramScreenshotDirective(parent):
     option_spec = parent.option_spec.copy()
     option_spec.update(dict(
@@ -67,6 +75,7 @@ class ProgramScreenshotDirective(parent):
                        timeout=directives.nonnegative_int,
                        bgcolor=directives.unchanged,
                        ))
+
     def run(self):
         screen = self.options.get('screen', '1024x768')
         screen = tuple(map(int, screen.split('x')))
@@ -75,14 +84,14 @@ class ProgramScreenshotDirective(parent):
         bgcolor = self.options.get('bgcolor', 'white')
         visible = 'visible' in self.options
         cmd = str(self.arguments[0])
-        
+
         global image_id
         f = 'screenshot_id%s.png' % (str(image_id))
         image_id += 1
-        fabs = path.path(self.src).dirname() / (f)
+        fabs = path.path(get_src(self)).dirname() / (f)
         images_to_delete.append(fabs)
 
-        o = prog_shot(cmd, fabs, screen_size=screen, wait=wait, 
+        o = prog_shot(cmd, fabs, screen_size=screen, wait=wait,
                       timeout=timeout, visible=visible, bgcolor=bgcolor)
 
         self.arguments[0] = f
@@ -90,7 +99,7 @@ class ProgramScreenshotDirective(parent):
 
         output = ''
         if 'stdout' in self.options:
-            output += o[0] 
+            output += o[0]
             if o[0]:
                 output += '\n'
 
@@ -101,15 +110,15 @@ class ProgramScreenshotDirective(parent):
 
         if 'prompt' in self.options:
             # TODO:
-            #if app.config.programoutput_use_ansi:
+            # if app.config.programoutput_use_ansi:
             #    # enable ANSI support, if requested by config
             #    from sphinxcontrib.ansi import ansi_literal_block
             #    node_class = ansi_literal_block
-            #else:
+            # else:
             #    node_class = nodes.literal_block
 
             # TODO: get app
-            #tmpl = app.config.programoutput_prompt_template
+            # tmpl = app.config.programoutput_prompt_template
             tmpl = '$ %(command)s\n%(output)s'
             output = tmpl % dict(command=cmd, output=output)
 
@@ -119,6 +128,7 @@ class ProgramScreenshotDirective(parent):
 
         return x
 
+
 def cleanup(app, exception):
     for x in images_to_delete:
         f = path.path(x)
@@ -126,10 +136,10 @@ def cleanup(app, exception):
             log.debug('removing image:' + x)
             f.remove()
 
+
 def setup(app):
-    #app.add_config_value('programoutput_use_ansi', False, 'env')
-    #app.add_config_value('programscreenshot_prompt_template',
+    # app.add_config_value('programoutput_use_ansi', False, 'env')
+    # app.add_config_value('programscreenshot_prompt_template',
     #                     '$ %(command)s\n%(output)s', 'env')
     app.add_directive('program-screenshot', ProgramScreenshotDirective)
     app.connect('build-finished', cleanup)
-
